==> 0.0.1.tar.gz: android/src/main/java/cn/cheney/router_plugin/RouterPlugin.java <==
package cn.cheney.router_plugin;

import android.text.TextUtils;

import java.util.Map;

import cn.cheney.xrouter.core.RouteCallback;
import cn.cheney.xrouter.core.XRouter;
import cn.cheney.xrouter.core.call.PageCall;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * RouterPlugin
 */
public class RouterPlugin implements MethodCallHandler {
    /**
     * Plugin registration.
     */
    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "router_plugin");
        channel.setMethodCallHandler(new RouterPlugin());
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        Map<String, Object> argumentMap = call.arguments();
        if (null == argumentMap) {
            result.error("EMPTY_ARGUMENTS", "EMPTY_ARGUMENTS", null);
            return;
        }
        String routerUrl = (String) argumentMap.get("url");
        if (TextUtils.isEmpty(routerUrl)) {
            result.error("EMPTY_URL", "EMPTY_URL", null);
            return;
        }
        Map<String, Object> paramsMap = (Map<String, Object>) argumentMap.get("params");
        switch (call.method) {
            case "page":
                page(routerUrl, paramsMap, result);
                break;
            case "method":
                method(routerUrl, paramsMap, result);
                break;
            default:
                result.notImplemented();
        }
    }

    private void page(String url, Map<String, Object> params, Result result) {
        PageCall pageCall = XRouter.page(url);
        if (null != params && !params.isEmpty()) {
            for (Map.Entry<String, Object> entry : params.entrySet()) {
                pageCall.put(entry.getKey(), entry.getValue());
            }
        }
        result.success(pageCall.call());
    }


    private void method(String url, Map<String, Object> params, final Result result) {
        cn.cheney.xrouter.core.call.MethodCall<Object> methodCall = XRouter.method(url);
        if (null != params && !params.isEmpty()) {
            for (Map.Entry<String, Object> entry : params.entrySet()) {
                methodCall.put(entry.getKey(), entry.getValue());
            }
        }
        Object syncResult = methodCall.call(new RouteCallback() {
            @Override
            public void onResult(Map<String, Object> asyncResult) {
                result.success(asyncResult);
            }
        });
        result.success(syncResult);
    }


}

==> 0.0.2.tar.gz: android/src/main/java/cn/cheney/router_plugin/RouterPlugin.java <==
package cn.cheney.router_plugin;

import android.text.TextUtils;

import java.util.Map;

import cn.cheney.xrouter.core.RouteCallback;
import cn.cheney.xrouter.core.XRouter;
import cn.cheney.xrouter.core.call.PageCall;
import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * RouterPlugin
 */
public class RouterPlugin implements MethodCallHandler {

    private Registrar mRegistrar;

    /**
     * Plugin registration.
     */
    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "router_plugin");
        channel.setMethodCallHandler(new RouterPlugin(registrar));

    }

    private RouterPlugin(Registrar registrar) {
        this.mRegistrar = registrar;
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        Map<String, Object> argumentMap = call.arguments();
        if (null == argumentMap) {
            result.error("EMPTY_ARGUMENTS", "EMPTY_ARGUMENTS", null);
            return;
        }
        String routerUrl = (String) argumentMap.get("url");
        if (TextUtils.isEmpty(routerUrl)) {
            result.error("EMPTY_URL", "EMPTY_URL", null);
            return;
        }
        Map<String, Object> paramsMap = (Map<String, Object>) argumentMap.get("params");
        switch (call.method) {
            case "page":
                page(routerUrl, paramsMap, result);
                break;
            case "method":
                method(routerUrl, paramsMap, result);
                break;
            default:
                result.notImplemented();
        }
    }

    private void page(String url, Map<String, Object> params, Result result) {
        PageCall pageCall = XRouter.page(url);
        if (null != params && !params.isEmpty()) {
            for (Map.Entry<String, Object> entry : params.entrySet()) {
                pageCall.put(entry.getKey(), entry.getValue());
            }
        }
        result.success(pageCall.call());
    }


    private void method(String url, Map<String, Object> params, final Result result) {
        final cn.cheney.xrouter.core.call.MethodCall<Object> methodCall = XRouter.method(url);
        methodCall.put("context", mRegistrar.activity());
        if (null != params && !params.isEmpty()) {
            for (Map.Entry<String, Object> entry : params.entrySet()) {
                methodCall.put(entry.getKey(), entry.getValue());
            }
        }
        Object syncResult = methodCall.call(new RouteCallback() {
            @Override
            public void onResult(Map<String, Object> asyncResult) {
                if (methodCall.isAsync()) {
                    result.success(asyncResult);
                }
            }
        });
        if (!methodCall.isAsync()) {
            result.success(syncResult);
        }
    }


}
